package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.service.ITcAqgService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 网络安全官Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@RequestMapping("/tcZz/networkEcology/aqg")
public class TcAqgController extends BaseController
{
    @Autowired
    private ITcAqgService tcAqgService;

    /**
     * 查询网络安全官列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:aqg:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcAqg tcAqg)
    {
        startPage();
        List<TcAqg> list = tcAqgService.selectTcAqgList(tcAqg);
        return getDataTable(list);
    }

    /**
     * 导出网络安全官列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:aqg:export')")
    @Log(title = "网络安全官", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcAqg tcAqg)
    {
        List<TcAqg> list = tcAqgService.selectTcAqgList(tcAqg);
        ExcelUtil<TcAqg> util = new ExcelUtil<TcAqg>(TcAqg.class);
        util.exportExcel(response, list, "网络安全官数据");
    }

    /**
     * 获取网络安全官详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:aqg:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcAqgService.selectTcAqgById(id));
    }

    /**
     * 新增网络安全官
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:aqg:add')")
    @Log(title = "网络安全官", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcAqg tcAqg)
    {
        return toAjax(tcAqgService.insertTcAqg(tcAqg));
    }

    /**
     * 修改网络安全官
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:aqg:edit')")
    @Log(title = "网络安全官", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcAqg tcAqg)
    {
        return toAjax(tcAqgService.updateTcAqg(tcAqg));
    }

    /**
     * 删除网络安全官
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:aqg:remove')")
    @Log(title = "网络安全官", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcAqgService.deleteTcAqgByIds(ids));
    }
}
