package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcFb;
import com.ruoyi.tcZz.service.ITcFbService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 上级媒体、本地发布Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@RequestMapping("/tcZz/networkEcology/fb")
public class TcFbController extends BaseController
{
    @Autowired
    private ITcFbService tcFbService;

    /**
     * 查询上级媒体、本地发布列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:fb:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcFb tcFb)
    {
        startPage();
        List<TcFb> list = tcFbService.selectTcFbList(tcFb);
        return getDataTable(list);
    }

    /**
     * 导出上级媒体、本地发布列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:fb:export')")
    @Log(title = "上级媒体、本地发布", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcFb tcFb)
    {
        List<TcFb> list = tcFbService.selectTcFbList(tcFb);
        ExcelUtil<TcFb> util = new ExcelUtil<TcFb>(TcFb.class);
        util.exportExcel(response, list, "上级媒体、本地发布数据");
    }

    /**
     * 获取上级媒体、本地发布详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:fb:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcFbService.selectTcFbById(id));
    }

    /**
     * 新增上级媒体、本地发布
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:fb:add')")
    @Log(title = "上级媒体、本地发布", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcFb tcFb)
    {
        return toAjax(tcFbService.insertTcFb(tcFb));
    }

    /**
     * 修改上级媒体、本地发布
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:fb:edit')")
    @Log(title = "上级媒体、本地发布", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcFb tcFb)
    {
        return toAjax(tcFbService.updateTcFb(tcFb));
    }

    /**
     * 删除上级媒体、本地发布
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:fb:remove')")
    @Log(title = "上级媒体、本地发布", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcFbService.deleteTcFbByIds(ids));
    }
}
