package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcSjly;
import com.ruoyi.tcZz.service.ITcSjlyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 硬探针、软探针Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/ryz")
public class TcSjlyController extends BaseController
{
    @Autowired
    private ITcSjlyService tcSjlyService;

    /**
     * 查询硬探针、软探针列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:ryz:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcSjly tcSjly)
    {
        startPage();
        List<TcSjly> list = tcSjlyService.selectTcSjlyList(tcSjly);
        return getDataTable(list);
    }

    /**
     * 导出硬探针、软探针列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:ryz:export')")
    @Log(title = "硬探针、软探针", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcSjly tcSjly)
    {
        List<TcSjly> list = tcSjlyService.selectTcSjlyList(tcSjly);
        ExcelUtil<TcSjly> util = new ExcelUtil<TcSjly>(TcSjly.class);
        util.exportExcel(response, list, "硬探针、软探针数据");
    }

    /**
     * 获取硬探针、软探针详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:ryz:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcSjlyService.selectTcSjlyById(id));
    }

    /**
     * 新增硬探针、软探针
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:ryz:add')")
    @Log(title = "硬探针、软探针", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcSjly tcSjly)
    {
        return toAjax(tcSjlyService.insertTcSjly(tcSjly));
    }

    /**
     * 修改硬探针、软探针
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:ryz:edit')")
    @Log(title = "硬探针、软探针", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcSjly tcSjly)
    {
        return toAjax(tcSjlyService.updateTcSjly(tcSjly));
    }

    /**
     * 删除硬探针、软探针
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:ryz:remove')")
    @Log(title = "硬探针、软探针", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcSjlyService.deleteTcSjlyByIds(ids));
    }
}
