package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcWlmqfzr;
import com.ruoyi.tcZz.service.ITcWlmqfzrService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 网络民情负责人Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@RequestMapping("/tcZz/networkEcology/wlmqfzr")
public class TcWlmqfzrController extends BaseController
{
    @Autowired
    private ITcWlmqfzrService tcWlmqfzrService;

    /**
     * 查询网络民情负责人列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:wlmqfzr:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcWlmqfzr tcWlmqfzr)
    {
        startPage();
        List<TcWlmqfzr> list = tcWlmqfzrService.selectTcWlmqfzrList(tcWlmqfzr);
        return getDataTable(list);
    }

    /**
     * 导出网络民情负责人列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:wlmqfzr:export')")
    @Log(title = "网络民情负责人", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWlmqfzr tcWlmqfzr)
    {
        List<TcWlmqfzr> list = tcWlmqfzrService.selectTcWlmqfzrList(tcWlmqfzr);
        ExcelUtil<TcWlmqfzr> util = new ExcelUtil<TcWlmqfzr>(TcWlmqfzr.class);
        util.exportExcel(response, list, "网络民情负责人数据");
    }

    /**
     * 获取网络民情负责人详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:wlmqfzr:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcWlmqfzrService.selectTcWlmqfzrById(id));
    }

    /**
     * 新增网络民情负责人
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:wlmqfzr:add')")
    @Log(title = "网络民情负责人", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcWlmqfzr tcWlmqfzr)
    {
        return toAjax(tcWlmqfzrService.insertTcWlmqfzr(tcWlmqfzr));
    }

    /**
     * 修改网络民情负责人
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:wlmqfzr:edit')")
    @Log(title = "网络民情负责人", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcWlmqfzr tcWlmqfzr)
    {
        return toAjax(tcWlmqfzrService.updateTcWlmqfzr(tcWlmqfzr));
    }

    /**
     * 删除网络民情负责人
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:wlmqfzr:remove')")
    @Log(title = "网络民情负责人", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcWlmqfzrService.deleteTcWlmqfzrByIds(ids));
    }
}
