package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcWpy;
import com.ruoyi.tcZz.service.ITcWpyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 网评员Controller
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@RequestMapping("/tcZz/networkEcology/wpy")
public class TcWpyController extends BaseController
{
    @Autowired
    private ITcWpyService tcWpyService;

    /**
     * 查询网评员列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:wpy:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcWpy tcWpy)
    {
        startPage();
        List<TcWpy> list = tcWpyService.selectTcWpyList(tcWpy);
        return getDataTable(list);
    }

    /**
     * 导出网评员列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:wpy:export')")
    @Log(title = "网评员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWpy tcWpy)
    {
        List<TcWpy> list = tcWpyService.selectTcWpyList(tcWpy);
        ExcelUtil<TcWpy> util = new ExcelUtil<TcWpy>(TcWpy.class);
        util.exportExcel(response, list, "网评员数据");
    }

    /**
     * 获取网评员详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:wpy:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcWpyService.selectTcWpyById(id));
    }

    /**
     * 新增网评员
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:wpy:add')")
    @Log(title = "网评员", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcWpy tcWpy)
    {
        return toAjax(tcWpyService.insertTcWpy(tcWpy));
    }

    /**
     * 修改网评员
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:wpy:edit')")
    @Log(title = "网评员", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcWpy tcWpy)
    {
        return toAjax(tcWpyService.updateTcWpy(tcWpy));
    }

    /**
     * 删除网评员
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkEcology:wpy:remove')")
    @Log(title = "网评员", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcWpyService.deleteTcWpyByIds(ids));
    }
}
